@@ -36,10 +36,11 @@ struct _GtkHTMLPrivate {
 	GtkHTMLFontStyle insertion_font_style;
 
 	gboolean update_styles;
+	gboolean skip_update_cursor;
+	gboolean cursor_moved;
 
 	gint selection_type;
 
-	gchar *content_type;
 	char  *base_url;
 
 	GtkWidget *search_input_line;
